@@ -23,7 +23,7 @@ if __name__ == '__main__':
         'Qzd-Fingerprint': get_fingerprint()
     }
     qrunner.main(
-        case_path='test_case.py',
+        case_path='test_demo.py',
         platform='api',
         base_url='https://app-pre.qizhidao.com',
         headers=headers
