@@ -157,14 +157,6 @@ class TestCase(HttpRequest):
             file_name = file_name + '.png'
         self.driver.screenshot(file_name)
 
-    # def allure_shot(self, file_name: str):
-    #     """
-    #     截图并上传至allure
-    #     :param file_name: 如首页截图
-    #     :return:
-    #     """
-    #     self.driver.upload_pic(file_name)
-
     def assertStatusCode(self, status_code):
         """
         Asserts the HTTP status code
@@ -206,6 +198,14 @@ class TestCase(HttpRequest):
         else:
             assert search_value == value, f'{search_value} != {value}'
 
+    def assertCode(self, code):
+        """
+        断言返回json中的code
+        @param code: 0
+        @return:
+        """
+        self.assertPath('code', code)
+
 
 class Page:
     """
