@@ -93,8 +93,10 @@ class AndroidElement(object):
         """
         element = self._find_element(retry=retry, timeout=timeout)
         if element is None:
-            self._driver.screenshot(f'元素定位失败')
+            self._driver.screenshot(f'{self._kwargs}-定位失败')
             raise NoSuchElementException(f'{self._kwargs}-定位失败')
+        else:
+            self._driver.screenshot(f'{self._kwargs}')
         return element
 
     @property
