@@ -42,9 +42,9 @@ def request(func):
         # 处理请求头
         headers: dict = json_util.loads(conf.get_name('api', 'headers'))  # 从配置文件拿到登录用户请求头
         # 如果login=False，从请求头中删掉登录态相关的键值对
-        login_key = (conf.get_name('api', 'login_key')).split(',')
         login_status = kwargs.get('login', True)
         if not login_status:
+            login_key = (conf.get_name('api', 'login_key')).split(',')
             for key in login_key:
                 headers.pop(key)
         # 把上层请求方法的headers参数更新到headers里面
@@ -60,6 +60,15 @@ def request(func):
         #             conf_headers_dict.pop(key)
         #     headers.update(conf_headers_dict)
         kwargs['headers'] = headers
+
+        # 设置请求超时时间为5s
+        timeout_default = 5
+        timeout_set = kwargs.pop("timeout", None)
+        if timeout_set is not None:
+            kwargs['timeout'] = timeout_set
+        else:
+            kwargs['timeout'] = timeout_default
+
         cookies = kwargs.get("cookies", "")
         params = kwargs.get("params", "")
         data = kwargs.get("data", "")
@@ -110,47 +119,35 @@ class ResponseResult:
 
 class HttpRequest(object):
 
-    # def http_req(self, url, method=None, params=None, login=True, **kwargs):
-    #     if method == 'get':
-    #         self.get(url, params=params, login=login, **kwargs)
-    #     elif method == 'post':
-    #         self.post(url, json=params, login=login, **kwargs)
-    #     elif method == 'put':
-    #         self.put(url, data=params, login=login, **kwargs)
-    #     elif method == 'delete':
-    #         self.delete(url, login=login, **kwargs)
-    #     else:
-    #         print(f'不支持的请求方式: {method}')
-
     @request
-    def get(self, url, params=None, login=True, **kwargs):
+    def get(self, url, params=None, **kwargs):
         base_url = conf.get_name('api', 'base_url')
         if (base_url is not None) and ("http" not in url):
             url = base_url + url
-        return requests.get(url, params=params, **kwargs)
+        return requests.get(url, params=params, verify=False, **kwargs)
 
     @request
-    def post(self, url, data=None, json=None, login=True, **kwargs):
+    def post(self, url, data=None, json=None, **kwargs):
         base_url = conf.get_name('api', 'base_url')
         if (base_url is not None) and ("http" not in url):
             url = base_url + url
-        return requests.post(url, data=data, json=json, **kwargs)
+        return requests.post(url, data=data, json=json, verify=False, **kwargs)
 
     @request
-    def put(self, url, data=None, json=None, login=True, **kwargs):
+    def put(self, url, data=None, json=None, **kwargs):
         base_url = conf.get_name('api', 'base_url')
         if (base_url is not None) and ("http" not in url):
             url = base_url + url
         if json is not None:
             data = json_util.dumps(json)
-        return requests.put(url, data=data, **kwargs)
+        return requests.put(url, data=data, verify=False, **kwargs)
 
     @request
-    def delete(self, url, login=True, **kwargs):
+    def delete(self, url, **kwargs):
         base_url = conf.get_name('api', 'base_url')
         if (base_url is not None) and ("http" not in url):
             url = base_url + url
-        return requests.delete(url, **kwargs)
+        return requests.delete(url, verify=False, **kwargs)
 
     @property
     def response(self):
