@@ -33,24 +33,3 @@ class TimeoutException(QException):
     Thrown when a command does not complete in enough time.
     """
     pass
-
-
-class DeviceNotFoundException(QException):
-    """
-    设备未找到
-    """
-    pass
-
-
-class ElementNameEmptyException(QException):
-    """
-    控件名称为空
-    """
-    pass
-
-
-class ScreenFailException(QException):
-    """
-    截图失败
-    """
-    pass
\ No newline at end of file
